@@ -9,12 +9,17 @@ from i2a_chat_api_client.exceptions import I2AChatApiClientUnauthorizedException
     I2AChatApiClientNotFoundError
 
 
+class I2aChatApiServer:
+    STAGE = 'https://chat-server-stg.i2asolutions.com'
+    PRODUCTION = NotImplemented
+    LOCAL = 'http://0.0.0.0:8000'
+
+
 class I2AChatApiClient:
 
-    I2A_CHAT_API_SERVER_URL = 'https://chat-server-stg.i2asolutions.com'
-    I2A_CHAT_API_ROOT_PATH = 'server-to-server/v1'
-
-    def __init__(self, x_application_secret):
+    def __init__(self, x_application_secret, server_url=I2aChatApiServer.STAGE):
+        self.server_url = server_url
+        self.api_root_path = 'server-to-server/v1'
         self.x_application_secret = x_application_secret
 
     def _required_headers(self):
@@ -23,7 +28,7 @@ class I2AChatApiClient:
         }
 
     def _get_full_url(self, uri):
-        return urljoin(self.I2A_CHAT_API_SERVER_URL, os.path.join(self.I2A_CHAT_API_ROOT_PATH, uri))
+        return urljoin(self.server_url, os.path.join(self.api_root_path, uri))
 
     @staticmethod
     def _status_code_message(response):
